<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ" sourcelanguage="en">
<context>
    <name>ArrowToolOptionsBox</name>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="430"/>
        <source>Z:</source>
        <translation>Z:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="431"/>
        <source>Position:</source>
        <translation>Poloha:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="432"/>
        <location filename="../../tnztools/tooloptions.cpp" line="515"/>
        <source>X:</source>
        <translation>V/Z:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="433"/>
        <location filename="../../tnztools/tooloptions.cpp" line="516"/>
        <source>Y:</source>
        <translation>S/J:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="448"/>
        <source>SO:</source>
        <translation>SO:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="453"/>
        <source>Rotation:</source>
        <translation>Otočení:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="469"/>
        <source>Global:</source>
        <translation>Celkové:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="470"/>
        <location filename="../../tnztools/tooloptions.cpp" line="496"/>
        <source>H:</source>
        <translation>V:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="471"/>
        <location filename="../../tnztools/tooloptions.cpp" line="497"/>
        <source>V:</source>
        <translation>S:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="576"/>
        <source>Flip Object Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="577"/>
        <source>Flip Object Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="578"/>
        <source>Rotate Object Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="579"/>
        <source>Rotate Object Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="599"/>
        <source>Pick:</source>
        <translation>Vybrat předmět:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="616"/>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="639"/>
        <source>(</source>
        <translation>(</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="641"/>
        <source>)</source>
        <translation>)</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="664"/>
        <source>Rotation</source>
        <translation>Otočení</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="688"/>
        <source>Scale</source>
        <translation>Měřítko</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="713"/>
        <source>Maintain:</source>
        <translation>Zachovat:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="733"/>
        <source>Shear</source>
        <translation>Stříhat</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="765"/>
        <source>Center Position</source>
        <translation>Střední poloha</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="978"/>
        <source>Table</source>
        <translation>Tabulka</translation>
    </message>
</context>
<context>
    <name>BrushTool</name>
    <message>
        <source>Size</source>
        <translation type="vanished">Velikost</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation type="vanished">Přesnost:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation type="vanished">Vyhlazení:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="vanished">Přednastavení:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="vanished">&lt;vlastní&gt;</translation>
    </message>
    <message>
        <source>Break</source>
        <translation type="vanished">Zlomit ostré úhly</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="vanished">Tlak</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation type="vanished">Čepice</translation>
    </message>
    <message>
        <source>Join</source>
        <translation type="vanished">Spojit</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation type="vanished">Zkosení:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="vanished">Rozsah:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="vanished">Přichytávání</translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="vanished">Vypnuto</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="vanished">Lineární</translation>
    </message>
    <message>
        <source>In</source>
        <translation type="vanished">Zpomalení na začátku</translation>
    </message>
    <message>
        <source>Out</source>
        <translation type="vanished">Zpomalení na konci</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="vanished">Nízký</translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="vanished">Střední</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="vanished">Vysoký</translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="vanished">Odřezek</translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="vanished">Zakulacený</translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="vanished">Rovný klobouček</translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="vanished">Ostrý ohyb</translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="vanished">Kulatý ohyb</translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="vanished">Zkosený ohyb</translation>
    </message>
</context>
<context>
    <name>BrushToolOptionsBox</name>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1827"/>
        <source>Preset Name</source>
        <translation>Název přednastavení</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1831"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1833"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>ControlPointEditorTool</name>
    <message>
        <location filename="../../tnztools/controlpointeditortool.cpp" line="218"/>
        <source>Auto Select Drawing</source>
        <translation>Automatický výběr kreslení</translation>
    </message>
    <message>
        <location filename="../../tnztools/controlpointeditortool.cpp" line="219"/>
        <source>Snap</source>
        <translation>Přichytávání</translation>
    </message>
    <message>
        <location filename="../../tnztools/controlpointeditortool.cpp" line="220"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../../tnztools/controlpointeditortool.cpp" line="221"/>
        <source>Rectangular</source>
        <translation>Obdélníkový</translation>
    </message>
    <message>
        <location filename="../../tnztools/controlpointeditortool.cpp" line="222"/>
        <source>Freehand</source>
        <translation>Kreslení od ruky</translation>
    </message>
    <message>
        <location filename="../../tnztools/controlpointeditortool.cpp" line="225"/>
        <source>Low</source>
        <translation>Nízký</translation>
    </message>
    <message>
        <location filename="../../tnztools/controlpointeditortool.cpp" line="226"/>
        <source>Med</source>
        <translation>Střední</translation>
    </message>
    <message>
        <location filename="../../tnztools/controlpointeditortool.cpp" line="227"/>
        <source>High</source>
        <translation>Vysoký</translation>
    </message>
</context>
<context>
    <name>ControlPointSelection</name>
    <message>
        <location filename="../../tnztools/controlpointselection.cpp" line="1013"/>
        <source>Set Linear Control Point</source>
        <translation>Nastavit lineární ovládací bod</translation>
    </message>
    <message>
        <location filename="../../tnztools/controlpointselection.cpp" line="1014"/>
        <source>Set Nonlinear Control Point</source>
        <translation>Nastavit nelineární ovládací bod</translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <location filename="../../tnztools/tooloptionscontrols.cpp" line="542"/>
        <source>current</source>
        <translation>Nynější</translation>
    </message>
</context>
<context>
    <name>EditTool</name>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="733"/>
        <source>Scale Constraint:</source>
        <translation>Omezení měřítka:</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="734"/>
        <location filename="../../tnztools/edittool.cpp" line="739"/>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="735"/>
        <source>A/R</source>
        <translation>A/R</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="736"/>
        <source>Mass</source>
        <translation>Hmota</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="738"/>
        <source>Auto Select Column</source>
        <translation>Automaticky vybrat sloupec</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="740"/>
        <source>Column</source>
        <translation>Sloupec</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="741"/>
        <source>Pegbar</source>
        <translation>Pruh na kolíky</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="743"/>
        <source>Global Key</source>
        <translation>Celkový klíč</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="744"/>
        <source>Lock Center X</source>
        <translation>Uzmknout střed [X]</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="745"/>
        <source>Lock Center Y</source>
        <translation>Uzmknout střed [Y]</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="746"/>
        <source>Lock Position X</source>
        <translation>Uzmknout polohu [X]</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="747"/>
        <source>Lock Position Y</source>
        <translation>Uzmknout polohu [Y]</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="748"/>
        <source>Lock Rotation</source>
        <translation>Uzmknout otočení</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="749"/>
        <source>Lock Shear H</source>
        <translation>Uzmknout střih vodorovně</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="750"/>
        <source>Lock Shear V</source>
        <translation>Uzmknout střih svisle</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="751"/>
        <source>Lock Scale H</source>
        <translation>Uzmknout měřítko vodorovně</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="752"/>
        <source>Lock Scale V</source>
        <translation>Uzmknout měřítko svisle</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="753"/>
        <source>Lock Global Scale</source>
        <translation>Uzmknout celkové měřítko</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="754"/>
        <source>X and Y Positions</source>
        <translation>Polohy X a Y</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="755"/>
        <source>Z Position</source>
        <translation>Poloha Z</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="756"/>
        <source>SO</source>
        <translation>SO</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="757"/>
        <location filename="../../tnztools/edittool.cpp" line="765"/>
        <source>Rotation</source>
        <translation>Otočení</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="758"/>
        <source>Global Scale</source>
        <translation>Celkové měřítko</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="759"/>
        <source>Horizontal and Vertical Scale</source>
        <translation>Vodorovné a svislé měřítko</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="760"/>
        <location filename="../../tnztools/edittool.cpp" line="767"/>
        <source>Shear</source>
        <translation>Stříhat</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="761"/>
        <source>Center Position</source>
        <translation>Střední poloha</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="763"/>
        <source>Active Axis</source>
        <translation>Činná osa</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="764"/>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="766"/>
        <source>Scale</source>
        <translation>Měřítko</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="768"/>
        <source>Center</source>
        <translation>Střed</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="769"/>
        <source>All</source>
        <translation>Vše</translation>
    </message>
</context>
<context>
    <name>EraserTool</name>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="428"/>
        <location filename="../../tnztools/rastererasertool.cpp" line="631"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="429"/>
        <location filename="../../tnztools/rastererasertool.cpp" line="645"/>
        <source>Selective</source>
        <translation>Výběrový</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="430"/>
        <location filename="../../tnztools/rastererasertool.cpp" line="646"/>
        <source>Invert</source>
        <translation>Obrátit</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="431"/>
        <location filename="../../tnztools/rastererasertool.cpp" line="647"/>
        <source>Frame Range</source>
        <translation>Rozsah snímku</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="432"/>
        <location filename="../../tnztools/rastererasertool.cpp" line="634"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="433"/>
        <location filename="../../tnztools/rastererasertool.cpp" line="635"/>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="434"/>
        <location filename="../../tnztools/rastererasertool.cpp" line="636"/>
        <source>Rectangular</source>
        <translation>Obdélníkový</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="435"/>
        <location filename="../../tnztools/rastererasertool.cpp" line="637"/>
        <source>Freehand</source>
        <translation>Kreslení od ruky</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="436"/>
        <location filename="../../tnztools/rastererasertool.cpp" line="638"/>
        <source>Polyline</source>
        <translation>Lomená čára</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="437"/>
        <source>Segment</source>
        <translation>Část</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="440"/>
        <source>Linear</source>
        <translation>Lineární</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="441"/>
        <source>Ease In</source>
        <translation>Zpomalení na začátku</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="442"/>
        <source>Ease Out</source>
        <translation>Zpomalení na konci</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorerasertool.cpp" line="443"/>
        <source>Ease In/Out</source>
        <translation>Zpomalení na začátku/na konci</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastererasertool.cpp" line="632"/>
        <source>Hardness:</source>
        <translation>Tvrdost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastererasertool.cpp" line="640"/>
        <source>Mode:</source>
        <translation>Režim:</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastererasertool.cpp" line="641"/>
        <source>Lines</source>
        <translation>Čáry</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastererasertool.cpp" line="642"/>
        <source>Areas</source>
        <translation>Plochy</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastererasertool.cpp" line="643"/>
        <source>Lines &amp; Areas</source>
        <translation>Čáry a plochy</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastererasertool.cpp" line="648"/>
        <source>Pencil Mode</source>
        <translation>Režim tužky</translation>
    </message>
</context>
<context>
    <name>FillTool</name>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1843"/>
        <source>Frame Range</source>
        <translation>Rozsah snímku</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1845"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1846"/>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1847"/>
        <source>Rectangular</source>
        <translation>Obdélníkový</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1848"/>
        <source>Freehand</source>
        <translation>Kreslení od ruky</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1849"/>
        <source>Polyline</source>
        <translation>Lomená čára</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1850"/>
        <source>Pick+Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1852"/>
        <source>Selective</source>
        <translation>Výběrový</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1854"/>
        <source>Mode:</source>
        <translation>Režim:</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1855"/>
        <source>Lines</source>
        <translation>Čáry</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1856"/>
        <source>Areas</source>
        <translation>Plochy</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1857"/>
        <source>Lines &amp; Areas</source>
        <translation>Čáry a plochy</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1859"/>
        <source>Onion Skin</source>
        <translation> Cibulový vzhled </translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1860"/>
        <source>Fill Depth</source>
        <translation>Hloubka výplně</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1861"/>
        <source>Segment</source>
        <translation>Část</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1862"/>
        <source>Maximum Gap</source>
        <translation>Největší mezera</translation>
    </message>
    <message>
        <location filename="../../tnztools/filltool.cpp" line="1863"/>
        <source>Autopaint Lines</source>
        <translation>Automatické malování čar</translation>
    </message>
</context>
<context>
    <name>FingerTool</name>
    <message>
        <location filename="../../tnztools/fingertool.cpp" line="333"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/fingertool.cpp" line="334"/>
        <source>Invert</source>
        <translation>Obrátit</translation>
    </message>
</context>
<context>
    <name>FullColorBrushTool</name>
    <message>
        <location filename="../../tnztools/fullcolorbrushtool.cpp" line="182"/>
        <location filename="../../tnztools/fullcolorbrushtool.cpp" line="187"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorbrushtool.cpp" line="183"/>
        <source>Pressure</source>
        <translation>Tlak</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorbrushtool.cpp" line="184"/>
        <location filename="../../tnztools/fullcolorbrushtool.cpp" line="188"/>
        <source>Opacity</source>
        <translation>Neprůhlednost</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorbrushtool.cpp" line="185"/>
        <source>Hardness:</source>
        <translation>Tvrdost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorbrushtool.cpp" line="186"/>
        <source>Preset:</source>
        <translation>Přednastavení:</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorbrushtool.cpp" line="189"/>
        <source>Eraser</source>
        <translation>Guma</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorbrushtool.cpp" line="190"/>
        <source>Lock Alpha</source>
        <translation>Zamknout alfu</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorbrushtool.cpp" line="726"/>
        <source>&lt;custom&gt;</source>
        <translation>&lt;vlastní&gt;</translation>
    </message>
</context>
<context>
    <name>FullColorEraserTool</name>
    <message>
        <location filename="../../tnztools/fullcolorerasertool.cpp" line="414"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorerasertool.cpp" line="415"/>
        <source>Opacity:</source>
        <translation>Neprůhlednost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorerasertool.cpp" line="416"/>
        <source>Hardness:</source>
        <translation>Tvrdost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorerasertool.cpp" line="418"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorerasertool.cpp" line="419"/>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorerasertool.cpp" line="420"/>
        <source>Rectangular</source>
        <translation>Obdélníkový</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorerasertool.cpp" line="421"/>
        <source>Freehand</source>
        <translation>Kreslení od ruky</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorerasertool.cpp" line="422"/>
        <source>Polyline</source>
        <translation>Lomená čára</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorerasertool.cpp" line="424"/>
        <source>Invert</source>
        <translation>Obrátit</translation>
    </message>
    <message>
        <location filename="../../tnztools/fullcolorerasertool.cpp" line="425"/>
        <source>Frame Range</source>
        <translation>Rozsah snímku</translation>
    </message>
</context>
<context>
    <name>FullColorFillTool</name>
    <message>
        <location filename="../../tnztools/fullcolorfilltool.cpp" line="147"/>
        <source>Fill Depth</source>
        <translation>Hloubka výplně</translation>
    </message>
</context>
<context>
    <name>HandToolOptionsBox</name>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2779"/>
        <source>Reset Position</source>
        <translation>Obnovit výchozí polohu</translation>
    </message>
</context>
<context>
    <name>HookTool</name>
    <message>
        <location filename="../../tnztools/hooktool.cpp" line="185"/>
        <source>Snap</source>
        <translation>Přichytávání</translation>
    </message>
</context>
<context>
    <name>MagnetTool</name>
    <message>
        <location filename="../../tnztools/magnettool.cpp" line="156"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
</context>
<context>
    <name>PaintBrushTool</name>
    <message>
        <location filename="../../tnztools/paintbrushtool.cpp" line="356"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/paintbrushtool.cpp" line="358"/>
        <source>Mode:</source>
        <translation>Režim:</translation>
    </message>
    <message>
        <location filename="../../tnztools/paintbrushtool.cpp" line="359"/>
        <source>Lines</source>
        <translation>Čáry</translation>
    </message>
    <message>
        <location filename="../../tnztools/paintbrushtool.cpp" line="360"/>
        <source>Areas</source>
        <translation>Plochy</translation>
    </message>
    <message>
        <location filename="../../tnztools/paintbrushtool.cpp" line="361"/>
        <source>Lines &amp; Areas</source>
        <translation>Čáry a plochy</translation>
    </message>
    <message>
        <location filename="../../tnztools/paintbrushtool.cpp" line="363"/>
        <source>Selective</source>
        <translation>Výběrový</translation>
    </message>
    <message>
        <location filename="../../tnztools/paintbrushtool.cpp" line="364"/>
        <source>Lock Alpha</source>
        <translation type="unfinished">Zamknout alfu</translation>
    </message>
</context>
<context>
    <name>PinchTool</name>
    <message>
        <location filename="../../tnztools/pinchtool.cpp" line="111"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/pinchtool.cpp" line="112"/>
        <source>Corner:</source>
        <translation>Roh:</translation>
    </message>
    <message>
        <location filename="../../tnztools/pinchtool.cpp" line="113"/>
        <source>Manual</source>
        <translation>Ruční</translation>
    </message>
</context>
<context>
    <name>PlasticTool</name>
    <message>
        <location filename="../../tnztools/plastictool_meshedit.cpp" line="1118"/>
        <source>Swap Edge</source>
        <translation>Vyměnit okraj</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool_meshedit.cpp" line="1124"/>
        <source>Collapse Edge</source>
        <translation>Sbalit okraj</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool_meshedit.cpp" line="1129"/>
        <source>Split Edge</source>
        <translation>Rozdělit okraj</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool_meshedit.cpp" line="1135"/>
        <source>Cut Mesh</source>
        <translation>Vyjmout síť</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool_build.cpp" line="630"/>
        <source>Delete Vertex</source>
        <translation>Smazat vrchol</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool_animate.cpp" line="192"/>
        <source>Set Key</source>
        <translation>Nastavit klávesu</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool_animate.cpp" line="196"/>
        <source>Set Rest Key</source>
        <translation>Nastavit klávesu pro klidovou polohu</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool_animate.cpp" line="201"/>
        <source>Set Global Key</source>
        <translation>Nastavit celkovou klávesu</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool_animate.cpp" line="205"/>
        <source>Set Global Rest Key</source>
        <translation>Nastavit celkovou klávesu pro klidovou polohu</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="718"/>
        <source>Mode:</source>
        <translation>Režim:</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="720"/>
        <source>Edit Mesh</source>
        <translation>Upravit síť</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="721"/>
        <source>Paint Rigid</source>
        <translation>Malovat neohebný</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="722"/>
        <source>Build Skeleton</source>
        <translation>Postavit kostru</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="723"/>
        <source>Animate</source>
        <translation>Animovat</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="726"/>
        <source>Vertex Name:</source>
        <translation>Název vrcholu:</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="727"/>
        <source>Allow Stretching</source>
        <translation>Povolit roztažení</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="728"/>
        <source>Snap To Mesh</source>
        <translation>Přichytávat k síti</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="729"/>
        <source>Thickness</source>
        <translation>Tloušťka</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="733"/>
        <source>Rigid</source>
        <translation>Tuhý</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="734"/>
        <source>Flex</source>
        <translation>Ohebný</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="736"/>
        <source>Global Key</source>
        <translation>Celková klávesa</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="737"/>
        <source>Keep Distance</source>
        <translation>Zachovat odstup</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="738"/>
        <source>Angle Bounds</source>
        <translation>Ohraničení úhlu</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1239"/>
        <source>A group of skeletons already exists for current column. Replacing it will also substitute any existing vertex animation.

Do you want to continue?</source>
        <translation>V nynějším sloupci již existuje skupina koster. Její nahrazení rovněž nahradí všechny stávající animace vrcholu.

Chcete pokračovat?</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1243"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1243"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1457"/>
        <source>Copy Skeleton</source>
        <translation>Kopírovat kostru</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1464"/>
        <source>Paste Skeleton</source>
        <translation>Vložit kostru</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1488"/>
        <source>Show Mesh</source>
        <translation>Ukázat síť</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1495"/>
        <source>Show Rigidity</source>
        <translation>Ukázat ztuhlost</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1502"/>
        <source>Show SO</source>
        <translation>Ukázat SO</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1509"/>
        <source>Show Skeleton Onion Skin</source>
        <translation>Ukáza cibulový vzhled kostry</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1587"/>
        <source>The previous vertex name will be discarded, and all associated keys will be lost.

Do you want to proceed?</source>
        <translation>Předchozí název vrcholu bude zahozen a všechny přiřazené klávesy budou ztraceny.

Chcete pokračovat?</translation>
    </message>
</context>
<context>
    <name>PlasticToolOptionsBox</name>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="406"/>
        <source>Create Mesh</source>
        <translation>Vytvořit síť</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="409"/>
        <source>Skeleton:</source>
        <translation>Kostra:</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="476"/>
        <source>Distance</source>
        <translation>Odstup</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="485"/>
        <source>Angle</source>
        <translation>Úhel</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="494"/>
        <source>SO</source>
        <translation>SO</translation>
    </message>
</context>
<context>
    <name>PrimitiveParam</name>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="476"/>
        <source>Shape:</source>
        <translation>Tvar:</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="477"/>
        <source>Rectangle</source>
        <translation>Obdélník</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="478"/>
        <source>Circle</source>
        <translation>Kruh</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="479"/>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="480"/>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="481"/>
        <source>Polyline</source>
        <translation>Lomená čára</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="482"/>
        <source>Arc</source>
        <translation>Oblouk</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="483"/>
        <source>MultiArc</source>
        <translation>Víceobloukový</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="484"/>
        <source>Polygon</source>
        <translation>Mnohoúhelník</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="486"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="487"/>
        <source>Thickness:</source>
        <translation>Tloušťka:</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="488"/>
        <source>Opacity:</source>
        <translation>Neprůhlednost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="489"/>
        <source>Hardness:</source>
        <translation>Tvrdost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="490"/>
        <source>Polygon Sides:</source>
        <translation>Strany mnohoúhelníku:</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="491"/>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="492"/>
        <source>Auto Group</source>
        <translation>Automatické seskupení</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="493"/>
        <source>Auto Fill</source>
        <translation>Automatické vyplnění</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="494"/>
        <source>Smooth</source>
        <translation>Vyhlazení</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="495"/>
        <source>Selective</source>
        <translation>Výběrový</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="496"/>
        <source>Pencil Mode</source>
        <translation>Režim tužky</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="498"/>
        <source>Cap</source>
        <translation>Čepice</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="499"/>
        <source>Butt cap</source>
        <translation>Odřezek</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="500"/>
        <source>Round cap</source>
        <translation>Zakulacený</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="501"/>
        <source>Projecting cap</source>
        <translation>Rovný klobouček</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="503"/>
        <source>Join</source>
        <translation>Spojit</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="504"/>
        <source>Miter join</source>
        <translation>Ostrý ohyb</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="505"/>
        <source>Round join</source>
        <translation>Kulatý ohyb</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="506"/>
        <source>Bevel join</source>
        <translation>Zkosený ohyb</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="508"/>
        <source>Miter:</source>
        <translation>Zkosení:</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="509"/>
        <source>Snap</source>
        <translation>Přichytávání</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="512"/>
        <source>Low</source>
        <translation>Nízký</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="513"/>
        <source>Med</source>
        <translation>Střední</translation>
    </message>
    <message>
        <location filename="../../tnztools/geometrictool.cpp" line="514"/>
        <source>High</source>
        <translation>Vysoký</translation>
    </message>
</context>
<context>
    <name>PumpTool</name>
    <message>
        <location filename="../../tnztools/pumptool.cpp" line="105"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/pumptool.cpp" line="106"/>
        <source>Accuracy:</source>
        <translation>Přesnost:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="885"/>
        <location filename="../../tnztools/geometrictool.cpp" line="1432"/>
        <source>Yes</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="885"/>
        <location filename="../../tnztools/geometrictool.cpp" line="1432"/>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location filename="../../tnztools/strokeselection.cpp" line="130"/>
        <location filename="../../tnztools/rasterselection.cpp" line="1154"/>
        <source>The copied selection cannot be pasted in the current drawing.</source>
        <translation>Zkopírovaný výběr nelze vložit do nynější kresby.</translation>
    </message>
    <message>
        <location filename="../../tnztools/strokeselection.cpp" line="450"/>
        <source>The selection cannot be updated. It is not editable.</source>
        <translation>Výběr nelze aktualizovat. Není upravitelný.</translation>
    </message>
    <message>
        <location filename="../../tnztools/strokeselection.cpp" line="507"/>
        <location filename="../../tnztools/strokeselection.cpp" line="621"/>
        <location filename="../../tnztools/rasterselection.cpp" line="1076"/>
        <source>The selection cannot be deleted. It is not editable.</source>
        <translation>Výběr nelze smazat. Není upravitelný.</translation>
    </message>
    <message>
        <location filename="../../tnztools/strokeselection.cpp" line="560"/>
        <location filename="../../tnztools/rasterselection.cpp" line="1196"/>
        <source>The selection cannot be pasted. It is not editable.</source>
        <translation>Výběr nelze vložit. Není upravitelný.</translation>
    </message>
    <message>
        <location filename="../../tnztools/rasterselection.cpp" line="410"/>
        <location filename="../../tnztools/rasterselection.cpp" line="575"/>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="221"/>
        <location filename="../../tnztools/tooloptions.cpp" line="233"/>
        <source>Min:</source>
        <translation>Nejméně:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="221"/>
        <location filename="../../tnztools/tooloptions.cpp" line="233"/>
        <source>Max:</source>
        <translation>Nejvíce:</translation>
    </message>
    <message>
        <location filename="../../tnztools/setsaveboxtool.cpp" line="57"/>
        <source>Set Save Box : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</source>
        <translation>Nastavit ukládací box: (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</translation>
    </message>
    <message>
        <location filename="../../tnztools/selectiontool.cpp" line="307"/>
        <source>Move Center</source>
        <translation>Posunout středovou polohu</translation>
    </message>
    <message>
        <location filename="../../tnztools/rgbpickertool.cpp" line="110"/>
        <source>RGB Picker (R%1, G%2, B%3)</source>
        <translation>Volič RGB (R%1, G%2, B%3)</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1589"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../tnztools/plastictool.cpp" line="1589"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="99"/>
        <source>Group</source>
        <translation>Seskupit</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="126"/>
        <source>Ungroup</source>
        <translation>Zrušit seskupení</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="222"/>
        <source> to Front</source>
        <translation> na přední stranu</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="223"/>
        <source> to Forward</source>
        <translation> do popředí</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="224"/>
        <source> to Back</source>
        <translation> na zadní stranu</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="225"/>
        <source> to Backward</source>
        <translation> do pozadí</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="227"/>
        <source>Move Group</source>
        <translation>Přesunout skupinu</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="485"/>
        <source>The selection cannot be grouped. It is not editable.</source>
        <translation>Výběr nelze seskupit. Není upravitelný.</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="508"/>
        <source>The selection cannot be entered. It is not editable.</source>
        <translation>Výběr nelze zadat. Není upravitelný.</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="553"/>
        <source>The selection cannot be ungrouped. It is not editable.</source>
        <translation>Výběr nelze odskupit. Není upravitelný.</translation>
    </message>
    <message>
        <location filename="../../tnztools/imagegrouping.cpp" line="714"/>
        <source>The selection cannot be moved. It is not editable.</source>
        <translation>Výběr nelze přesunout. Není upravitelný.</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittoolgadgets.cpp" line="287"/>
        <source>Modify Fx Gadget  </source>
        <translation>Změnit udělátko efektu</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="1696"/>
        <location filename="../../tnztools/tool.cpp" line="952"/>
        <source>The current column is locked.</source>
        <translation>Nynější sloupec je uzamknut.</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="1700"/>
        <location filename="../../tnztools/tool.cpp" line="955"/>
        <source>The current column is hidden.</source>
        <translation>Nynější sloupec je skryt.</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="1683"/>
        <location filename="../../tnztools/tool.cpp" line="959"/>
        <source>It is not possible to edit the audio column.</source>
        <translation>Není možné upravit sloupec zvuku.</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="1687"/>
        <location filename="../../tnztools/tool.cpp" line="964"/>
        <source>Note columns can only be edited in the xsheet or timeline.</source>
        <translation>Sloupce s poznámkami mohou být upravovány jen v XSheet nebo časové ose.</translation>
    </message>
    <message>
        <location filename="../../tnztools/tool.cpp" line="972"/>
        <source>The current tool cannot be used on a Level column.</source>
        <translation>Nynější nástroj nelze použít na sloupec úroveň.</translation>
    </message>
    <message>
        <location filename="../../tnztools/tool.cpp" line="977"/>
        <source>The current tool cannot be used on a Mesh column.</source>
        <translation>Nynější nástroj nelze použít na sloupec síť.</translation>
    </message>
    <message>
        <location filename="../../tnztools/edittool.cpp" line="1666"/>
        <location filename="../../tnztools/tool.cpp" line="986"/>
        <source>The current tool cannot be used in Level Strip mode.</source>
        <translation>Nynější nástroj nelze použít ve sloupci pruh úrovně.</translation>
    </message>
    <message>
        <location filename="../../tnztools/tool.cpp" line="945"/>
        <source>The current tool cannot be used to edit a motion path.</source>
        <translation>Nynější nástroj nelze použít na upravení cesty pohybu.</translation>
    </message>
    <message>
        <location filename="../../tnztools/tool.cpp" line="1004"/>
        <location filename="../../tnztools/tool.cpp" line="1066"/>
        <source>The current level is not editable.</source>
        <translation>Nynější úroveň není upravitelná.</translation>
    </message>
    <message>
        <location filename="../../tnztools/tool.cpp" line="1013"/>
        <source>The current tool cannot be used on a Vector Level.</source>
        <translation>Nynější nástroj nelze použít na vektorovou úroveň.</translation>
    </message>
    <message>
        <location filename="../../tnztools/tool.cpp" line="1018"/>
        <source>The current tool cannot be used on a Toonz Level.</source>
        <translation>Nynější nástroj nelze použít na úroveň Toonz.</translation>
    </message>
    <message>
        <location filename="../../tnztools/tool.cpp" line="1023"/>
        <source>The current tool cannot be used on a Raster Level.</source>
        <translation>Nynější nástroj nelze použít na rastrovou úroveň.</translation>
    </message>
    <message>
        <location filename="../../tnztools/tool.cpp" line="1028"/>
        <source>The current tool cannot be used on a Mesh Level.</source>
        <translation>Nynější nástroj nelze použít na úroveň síť.</translation>
    </message>
    <message>
        <location filename="../../tnztools/tool.cpp" line="1044"/>
        <source>The current tool cannot be used on a mesh-deformed level</source>
        <translation>Nynější nástroj nelze použít na úroveň zdeformovaná (přetvořená) síť.</translation>
    </message>
    <message>
        <location filename="../../tnztools/tool.cpp" line="1054"/>
        <source>The current frame is locked: any editing is forbidden.</source>
        <translation>Nynější snímek je uzamknut: jakékoli úpravy jsou zakázány.</translation>
    </message>
    <message>
        <location filename="../../include/tools/toolutils.h" line="180"/>
        <source>%1   Level : %2  Frame : %3</source>
        <translation>%1   Úroveň: %2  Snímek: %3</translation>
    </message>
    <message>
        <location filename="../../include/tools/toolutils.h" line="271"/>
        <location filename="../../include/tools/toolutils.h" line="294"/>
        <source>Modify Stroke Tool</source>
        <translation>Změnit nástroj na tah</translation>
    </message>
    <message>
        <location filename="../../include/tools/toolutils.h" line="384"/>
        <source>Modify Spline</source>
        <translation>Změnit křivku (spline)</translation>
    </message>
    <message>
        <location filename="../../tnztools/rasterselectiontool.h" line="71"/>
        <source>Deform Raster</source>
        <translation>Přetvořit rastr</translation>
    </message>
    <message>
        <location filename="../../tnztools/rasterselectiontool.h" line="94"/>
        <source>Transform Raster</source>
        <translation>Proměnit rastr</translation>
    </message>
    <message>
        <location filename="../../tnztools/cuttertool.cpp" line="449"/>
        <source>Snap At Intersection</source>
        <translation>Přichytit v průsečíku</translation>
    </message>
</context>
<context>
    <name>RGBPickerTool</name>
    <message>
        <location filename="../../tnztools/rgbpickertool.cpp" line="228"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../../tnztools/rgbpickertool.cpp" line="229"/>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
    <message>
        <location filename="../../tnztools/rgbpickertool.cpp" line="230"/>
        <source>Rectangular</source>
        <translation>Obdélníkový</translation>
    </message>
    <message>
        <location filename="../../tnztools/rgbpickertool.cpp" line="231"/>
        <source>Freehand</source>
        <translation>Kreslení od ruky</translation>
    </message>
    <message>
        <location filename="../../tnztools/rgbpickertool.cpp" line="232"/>
        <source>Polyline</source>
        <translation>Lomená čára</translation>
    </message>
    <message>
        <location filename="../../tnztools/rgbpickertool.cpp" line="234"/>
        <source>Passive Pick</source>
        <translation>Pasivní volba</translation>
    </message>
</context>
<context>
    <name>RGBPickerToolOptionsBox</name>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2453"/>
        <source>Pick Screen</source>
        <translation>Zvolit obrazovku</translation>
    </message>
</context>
<context>
    <name>RasterSelectionTool</name>
    <message>
        <location filename="../../tnztools/rasterselectiontool.cpp" line="1038"/>
        <source>Modify Savebox</source>
        <translation>Změnit ukládací box</translation>
    </message>
    <message>
        <location filename="../../tnztools/rasterselectiontool.cpp" line="1040"/>
        <source>No Antialiasing</source>
        <translation>Žádné vyhlazování</translation>
    </message>
</context>
<context>
    <name>RasterTapeTool</name>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="179"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="180"/>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="181"/>
        <source>Rectangular</source>
        <translation>Obdélníkový</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="182"/>
        <source>Freehand</source>
        <translation>Kreslení od ruky</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="183"/>
        <source>Polyline</source>
        <translation>Lomená čára</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="185"/>
        <source>Distance:</source>
        <translation>Odstup:</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="186"/>
        <source>Style Index:</source>
        <translation>Číslo stylu:</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="187"/>
        <source>current</source>
        <translation>Nynější</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="188"/>
        <source>Opacity:</source>
        <translation>Neprůhlednost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="189"/>
        <source>Frame Range</source>
        <translation>Rozsah snímku</translation>
    </message>
    <message>
        <location filename="../../tnztools/rastertapetool.cpp" line="190"/>
        <source>Angle:</source>
        <translation>Úhel:</translation>
    </message>
</context>
<context>
    <name>RotateTool</name>
    <message>
        <location filename="../../tnztools/viewtools.h" line="41"/>
        <source>Rotate On Camera Center</source>
        <translation>Otočit na střed kamey</translation>
    </message>
</context>
<context>
    <name>RotateToolOptionsBox</name>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2752"/>
        <source>Reset Rotation</source>
        <translation>Obnovit výchozí otočení</translation>
    </message>
</context>
<context>
    <name>RulerToolOptionsBox</name>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2213"/>
        <source>X:</source>
        <comment>ruler tool option</comment>
        <translation>X:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2219"/>
        <source>Y:</source>
        <comment>ruler tool option</comment>
        <translation>Y:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2227"/>
        <source>W:</source>
        <comment>ruler tool option</comment>
        <translation>Š:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2233"/>
        <source>H:</source>
        <comment>ruler tool option</comment>
        <translation>V:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2241"/>
        <source>A:</source>
        <comment>ruler tool option</comment>
        <translation>A:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2246"/>
        <source>L:</source>
        <comment>ruler tool option</comment>
        <translation>D:</translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <location filename="../../tnztools/selectiontool.cpp" line="926"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../../tnztools/selectiontool.cpp" line="927"/>
        <source>Rectangular</source>
        <translation>Obdélníkový</translation>
    </message>
    <message>
        <location filename="../../tnztools/selectiontool.cpp" line="928"/>
        <source>Freehand</source>
        <translation>Kreslení od ruky</translation>
    </message>
    <message>
        <location filename="../../tnztools/selectiontool.cpp" line="929"/>
        <source>Polyline</source>
        <translation>Lomená čára</translation>
    </message>
</context>
<context>
    <name>SelectionToolOptionsBox</name>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1123"/>
        <source>H:</source>
        <translation>V:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1125"/>
        <source>V:</source>
        <translation>S:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1127"/>
        <source>Link</source>
        <translation>Stanovit poměr stran</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1130"/>
        <location filename="../../tnztools/tooloptions.cpp" line="1131"/>
        <source>Rotation</source>
        <translation>Otočení</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1133"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1135"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1167"/>
        <source>Flip Selection Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1168"/>
        <source>Flip Selection Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1169"/>
        <source>Rotate Selection Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1170"/>
        <source>Rotate Selection Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1186"/>
        <source>Scale</source>
        <translation>Měřítko</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1207"/>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="1224"/>
        <location filename="../../tnztools/tooloptions.cpp" line="1225"/>
        <source>Thickness</source>
        <translation>Tloušťka</translation>
    </message>
</context>
<context>
    <name>ShiftTraceToolOptionBox</name>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2590"/>
        <source>Reset Previous</source>
        <translation>Nastavit znovu předchozí</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2591"/>
        <source>Reset Following</source>
        <translation>Nastavit znovu následující</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2593"/>
        <source>Previous Drawing</source>
        <translation>Předchozí kresba</translation>
    </message>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2594"/>
        <source>Following Drawing</source>
        <translation>Následující kresba</translation>
    </message>
</context>
<context>
    <name>SkeletonTool</name>
    <message>
        <location filename="../../tnztools/skeletontool.cpp" line="291"/>
        <source>Show Only Active Skeleton</source>
        <translation>Ukázat jen činnou kostru</translation>
    </message>
    <message>
        <location filename="../../tnztools/skeletontool.cpp" line="292"/>
        <source>Global Key</source>
        <translation>Celková klávesa</translation>
    </message>
    <message>
        <location filename="../../tnztools/skeletontool.cpp" line="293"/>
        <source>Mode:</source>
        <translation>Režim:</translation>
    </message>
    <message>
        <location filename="../../tnztools/skeletontool.cpp" line="294"/>
        <source>Build Skeleton</source>
        <translation>Postavit kostru</translation>
    </message>
    <message>
        <location filename="../../tnztools/skeletontool.cpp" line="295"/>
        <source>Animate</source>
        <translation>Animovat</translation>
    </message>
    <message>
        <location filename="../../tnztools/skeletontool.cpp" line="296"/>
        <source>Inverse Kinematics</source>
        <translation>Obrácená kinematika</translation>
    </message>
    <message>
        <location filename="../../tnztools/skeletontool.cpp" line="1611"/>
        <source>Reset Pinned Center</source>
        <translation>Obnovit výchozí stanovený střed</translation>
    </message>
</context>
<context>
    <name>StylePickerTool</name>
    <message>
        <location filename="../../tnztools/stylepickertool.cpp" line="272"/>
        <source>No current level.</source>
        <translation>Žádná nynější úroveň.</translation>
    </message>
    <message>
        <location filename="../../tnztools/stylepickertool.cpp" line="277"/>
        <source>Current level has no available palette.</source>
        <translation>Nynější úroveň nemá žádnou dostupnou paletu.</translation>
    </message>
    <message>
        <location filename="../../tnztools/stylepickertool.cpp" line="288"/>
        <source>Palette must have more than one palette to be organized.</source>
        <translation>Paleta musí mít více než jednu paletu, aby byla uspořádána.</translation>
    </message>
    <message>
        <location filename="../../tnztools/stylepickertool.cpp" line="329"/>
        <source>Mode:</source>
        <translation>Režim:</translation>
    </message>
    <message>
        <location filename="../../tnztools/stylepickertool.cpp" line="330"/>
        <source>Lines</source>
        <translation>Čáry</translation>
    </message>
    <message>
        <location filename="../../tnztools/stylepickertool.cpp" line="331"/>
        <source>Areas</source>
        <translation>Plochy</translation>
    </message>
    <message>
        <location filename="../../tnztools/stylepickertool.cpp" line="332"/>
        <source>Lines &amp; Areas</source>
        <translation>Čáry a plochy</translation>
    </message>
    <message>
        <location filename="../../tnztools/stylepickertool.cpp" line="333"/>
        <source>Passive Pick</source>
        <translation>Pasivní volba</translation>
    </message>
    <message>
        <location filename="../../tnztools/stylepickertool.cpp" line="334"/>
        <source>Organize Palette</source>
        <translation>Uspořádat paletu</translation>
    </message>
</context>
<context>
    <name>StylePickerToolOptionsBox</name>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2539"/>
        <source>With this option being activated, the picked style will be
moved to the end of the first page of the palette.</source>
        <translation>Se zapnutím této volby bude zvolený styl
přesunut na konec první strany palety.</translation>
    </message>
</context>
<context>
    <name>ToonzRasterBrushTool</name>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1097"/>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1104"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1098"/>
        <source>Hardness:</source>
        <translation>Tvrdost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1099"/>
        <source>Smooth:</source>
        <translation>Vyhlazení:</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1100"/>
        <source>Draw Order:</source>
        <translation>Pořadí kresby:</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1101"/>
        <source>Over All</source>
        <translation>Nad vše</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1102"/>
        <source>Under All</source>
        <translation>Pod vše</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1103"/>
        <source>Palette Order</source>
        <translation>Pořadí palety</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1107"/>
        <source>Preset:</source>
        <translation>Přednastavení:</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1108"/>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="2177"/>
        <source>&lt;custom&gt;</source>
        <translation>&lt;vlastní&gt;</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1109"/>
        <source>Pencil</source>
        <translation>Tužka</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1110"/>
        <source>Pressure</source>
        <translation>Tlak</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzrasterbrushtool.cpp" line="1111"/>
        <source>Lock Alpha</source>
        <translation type="unfinished">Zamknout alfu</translation>
    </message>
</context>
<context>
    <name>ToonzVectorBrushTool</name>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="583"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="584"/>
        <source>Accuracy:</source>
        <translation>Přesnost:</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="585"/>
        <source>Smooth:</source>
        <translation>Vyhlazení:</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="586"/>
        <source>Preset:</source>
        <translation>Přednastavení:</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="587"/>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="1734"/>
        <source>&lt;custom&gt;</source>
        <translation>&lt;vlastní&gt;</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="588"/>
        <source>Break</source>
        <translation>Zlomit ostré úhly</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="589"/>
        <source>Pressure</source>
        <translation>Tlak</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="590"/>
        <source>Cap</source>
        <translation>Čepice</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="591"/>
        <source>Join</source>
        <translation>Spojit</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="592"/>
        <source>Miter:</source>
        <translation>Zkosení:</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="593"/>
        <source>Range:</source>
        <translation>Rozsah:</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="594"/>
        <source>Snap</source>
        <translation>Přichytávání</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="596"/>
        <source>Off</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="597"/>
        <source>Linear</source>
        <translation>Lineární</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="598"/>
        <source>In</source>
        <translation>Zpomalení na začátku</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="599"/>
        <source>Out</source>
        <translation>Zpomalení na konci</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="600"/>
        <source>In&amp;Out</source>
        <translation>Začátek a konec</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="601"/>
        <source>Low</source>
        <translation>Nízký</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="602"/>
        <source>Med</source>
        <translation>Střední</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="603"/>
        <source>High</source>
        <translation>Vysoký</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="604"/>
        <source>Butt cap</source>
        <translation>Odřezek</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="605"/>
        <source>Round cap</source>
        <translation>Zakulacený</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="606"/>
        <source>Projecting cap</source>
        <translation>Rovný klobouček</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="607"/>
        <source>Miter join</source>
        <translation>Ostrý ohyb</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="608"/>
        <source>Round join</source>
        <translation>Kulatý ohyb</translation>
    </message>
    <message>
        <location filename="../../tnztools/toonzvectorbrushtool.cpp" line="609"/>
        <source>Bevel join</source>
        <translation>Zkosený ohyb</translation>
    </message>
</context>
<context>
    <name>TrackerTool</name>
    <message>
        <location filename="../../tnztools/trackertool.cpp" line="255"/>
        <source>Width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <location filename="../../tnztools/trackertool.cpp" line="256"/>
        <source>Height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location filename="../../tnztools/trackertool.cpp" line="257"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location filename="../../tnztools/trackertool.cpp" line="258"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
</context>
<context>
    <name>TypeTool</name>
    <message>
        <location filename="../../tnztools/typetool.cpp" line="456"/>
        <source>Font:</source>
        <translation>Písmo:</translation>
    </message>
    <message>
        <location filename="../../tnztools/typetool.cpp" line="457"/>
        <source>Style:</source>
        <translation>Styl:</translation>
    </message>
    <message>
        <location filename="../../tnztools/typetool.cpp" line="458"/>
        <source>Vertical Orientation</source>
        <translation>Svislé natočení</translation>
    </message>
    <message>
        <location filename="../../tnztools/typetool.cpp" line="459"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
</context>
<context>
    <name>VectorSelectionTool</name>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1328"/>
        <source>Mode:</source>
        <translation>Režim:</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1329"/>
        <source>Standard</source>
        <translation>Standardní</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1330"/>
        <source>Selected Frames</source>
        <translation>Vybrané snímky</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1331"/>
        <source>Whole Level</source>
        <translation>Celá úroveň</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1332"/>
        <source>Same Style</source>
        <translation>Stejný styl</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1334"/>
        <source>Same Style on Selected Frames</source>
        <translation>Stejný styl na vybrané snímky</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1336"/>
        <source>Same Style on Whole Level</source>
        <translation>Stejný styl na celou úroveň</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1337"/>
        <source>Boundary Strokes</source>
        <translation>Hraniční tahy</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1339"/>
        <source>Boundaries on Selected Frames</source>
        <translation>Hraniční čáry na vybrané snímky</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1341"/>
        <source>Boundaries on Whole Level</source>
        <translation>Hraniční čáry na celou úroveň</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1343"/>
        <source>Include Intersection</source>
        <translation>Zahrnout průsečík</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1344"/>
        <source>Preserve Thickness</source>
        <translation>Zachovat tloušťku</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1346"/>
        <source>Cap</source>
        <translation>Čepice</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1347"/>
        <source>Butt cap</source>
        <translation>Odřezek</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1348"/>
        <source>Round cap</source>
        <translation>Zakulacený</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1349"/>
        <source>Projecting cap</source>
        <translation>Rovný klobouček</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1351"/>
        <source>Join</source>
        <translation>Spojit</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1352"/>
        <source>Miter join</source>
        <translation>Ostrý ohyb</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1353"/>
        <source>Round join</source>
        <translation>Kulatý ohyb</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1354"/>
        <source>Bevel join</source>
        <translation>Zkosený ohyb</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectorselectiontool.cpp" line="1356"/>
        <source>Miter:</source>
        <translation>Zkosení:</translation>
    </message>
</context>
<context>
    <name>VectorTapeTool</name>
    <message>
        <location filename="../../tnztools/vectortapetool.cpp" line="260"/>
        <source>Smooth</source>
        <translation>Vyhladit</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectortapetool.cpp" line="261"/>
        <source>Join Vectors</source>
        <translation>Spojit vektory</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectortapetool.cpp" line="262"/>
        <source>Distance</source>
        <translation>Odstup</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectortapetool.cpp" line="264"/>
        <source>Mode:</source>
        <translation>Režim:</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectortapetool.cpp" line="265"/>
        <source>Endpoint to Endpoint</source>
        <translation>Koncový bod ke koncovému bodu</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectortapetool.cpp" line="266"/>
        <source>Endpoint to Line</source>
        <translation>Koncový bod k čáře</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectortapetool.cpp" line="267"/>
        <source>Line to Line</source>
        <translation>Čára k čáře</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectortapetool.cpp" line="269"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectortapetool.cpp" line="270"/>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
    <message>
        <location filename="../../tnztools/vectortapetool.cpp" line="271"/>
        <source>Rectangular</source>
        <translation>Obdélníkový</translation>
    </message>
</context>
<context>
    <name>ZoomToolOptionsBox</name>
    <message>
        <location filename="../../tnztools/tooloptions.cpp" line="2725"/>
        <source>Reset Zoom</source>
        <translation>Obnovit výchozí zvětšení</translation>
    </message>
</context>
</TS>
